summaryrefslogtreecommitdiff
path: root/scripts/rebuilddb_psql.sh
diff options
context:
space:
mode:
Diffstat (limited to 'scripts/rebuilddb_psql.sh')
-rwxr-xr-xscripts/rebuilddb_psql.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/scripts/rebuilddb_psql.sh b/scripts/rebuilddb_psql.sh
index 9ade515ad..6b15b9212 100755
--- a/scripts/rebuilddb_psql.sh
+++ b/scripts/rebuilddb_psql.sh
@@ -15,7 +15,7 @@
#
# You MUST run this script as the 'postgres' user.
# You MUST be able to write to /tmp/rebuilddb_psql.sql
# You MUST specify the laconica database user and database name on the
# command line, e.g. ./rebuilddb_psql.sh myuser mydbname
#
@@ -27,7 +27,7 @@ cd `dirname $0`
pg_dump -a -D --disable-trigger $DB > /tmp/rebuilddb_psql.sql
psql -c "drop schema public cascade; create schema public;" $DB
psql -c "grant all privileges on schema public to $user;" $DB
-psql $DB < ../db/laconica_pg.sql
+psql $DB < ../db/statusnet_pg.sql
psql $DB < /tmp/rebuilddb_psql.sql
for tab in `psql -c '\dts' $DB -tA | cut -d\| -f2`; do
psql -c "ALTER TABLE \"$tab\" OWNER TO $user;" $DB
@@ -15,7 +15,7 @@
# You MUST run this script as the 'postgres' user.
# You MUST be able to write to /tmp/rebuilddb_psql.sql
-# You MUST specify the laconica database user and database name on the
+# You MUST specify the statusnet database user and database name on the
# command line, e.g. ./rebuilddb_psql.sh myuser mydbname
#